@@ -12,7 +12,7 @@ use File::HomeDir;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.044'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -61,7 +61,6 @@ sub _build_pausecfg {
     while (<$fh>) {
         next if /^ \s* (?: [#].*)? $/x;
         my ($k, $v) = /^ \s* (\w+) \s+ (.+?) \s* $/x;
-        next unless $k;
         $cfg->{$k} = $v;
     }
 
@@ -71,7 +70,8 @@ sub _build_pausecfg {
 #------------------------------------------------------------------------------
 1;
 
-__END__
+
+
 
 =pod
 
@@ -83,7 +83,7 @@ Pinto::Role::PauseConfig - Something that has a pause config attribute
 
 =head1 VERSION
 
-version 0.065_04
+version 0.044
 
 =head1 ATTRIBUTES
 
@@ -99,7 +99,7 @@ Returns a hashref representing the data of the PAUSE config file.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -109,3 +109,6 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
